Reference / API
=========================================

.. module:: pyDataverse

This part of the documentation covers all the interfaces / APIs of the pyDataverse modules.


Where pyDataverse depends on external libraries, we document the most
important right here and provide links to the canonical documentation outside of scope.


API Interface
-----------------------------

Access all of Dataverse APIs.

.. automodule:: pyDataverse.api
   :members:
   :special-members:


Models Interface
-----------------------------

Use all metadata models of the Dataverse data-types (`Dataverse`, `Dataset`
and `Datafile`). This includes import, export and manipulation.

.. automodule:: pyDataverse.models
  :inherited-members:


Utils Interface
-----------------------------

Helper functions.

.. automodule:: pyDataverse.utils
  :members:


Auth Helpers
-----------------------------

.. automodule:: pyDataverse.auth
  :members:


Exceptions
-----------------------------

Custom exceptions.

.. automodule:: pyDataverse.exceptions
  :members:
